@@ -6,10 +6,10 @@
  * $Notice: See LICENSE.txt for modification and distribution information
  *                   Copyright © 2021 by Shen, Jen-Chieh $
  */
-pub const WHITESPACE_FACTOR: f32 = 5.0;
-pub const WHITESPACE_REDUCE: f32 = 0.5;
-pub const CLASS_FACTOR: f32 = 3.0;
-pub const FIRST_FACTOR: f32 = 85.0;
+pub const SEPARATOR_FACTOR: f32 = 10.0;
+pub const SEPARATOR_REDUCE: f32 = 0.5;
+pub const CLASS_FACTOR: f32 = 10.0;
+pub const FIRST_FACTOR: f32 = 3.0;
 pub const CLASS_REDUCE: f32 = 0.5;
 
 pub const DIST_WEIGHT: f32 = -10.0;
